@@ -1,5 +1,5 @@
 package CDP;
-our $VERSION = '0.03';
+our $VERSION = '0.031';
 
 use 5.008006;
 use strict;
@@ -185,45 +185,106 @@ require AutoLoader;
 
 1;
 __END__
-# Below is stub documentation for your module. You'd better edit it!
+#BEGIN Documentation
 
 =head1 NAME
 
-CDP - Perl extension for blah blah blah
+CDP - Perl wrapper R1Soft CDP (Constant Data Protection) API.
 
 =head1 SYNOPSIS
 
-  use CDP;
-  blah blah blah
+This module is designed to provide a cleaner procedurally driven 
+interface to the 
+
+You may import all methods:
+  use CDP qw/:ALL/;
+
+Or You may impliment each module independently.
+
+  use CDP::backupTask     qw /:ALL/;
+  use CDP::diskSafe       qw /:ALL/;
+  use CDP::mySQL          qw /:ALL/;
+  use CDP::taskRun        qw /:ALL/;
+  use CDP::volume         qw /:ALL/;
+  use CDP::Connect        qw /:ALL/;
+  use CDP::host           qw /:ALL/;
+  use CDP::storagepool    qw /:ALL/;
+  use CDP::user           qw /:ALL/;
+  use CDP::Dump           qw /:ALL/;
 
 =head1 DESCRIPTION
 
-Stub documentation for CDP, created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
+This is a wrapper module for the R1Soft CDP v2.0 API.
 
-Blah blah blah.
+The goal behind this project was to make a cleaner interface between
+the R1Soft API and Perl programs.
+
+By default this module does not autoload any methods and allows you to 
+import the specific methods you require.  However, I did write CDP.pm as
+a parent module to allow a quick and easy way to import everything.
+
+This module implements Frontier Client to make XML/Java Script calls to the CDP Server.
 
 =head2 EXPORT
 
 None by default.
 
+=head1 Dependencies
 
+  Frontier::Client
+
+=head1 Comparison
+
+Using Frontier::Client
+  use Frontier::Client;
+
+  # To connect:
+  my $u_name  = 'test';
+  my $pw      = 'password';
+  my $cdp_url = 'cdp.example.com';
+  
+  my $control_server_url = "http://$u_name:$pw\@$cdp_url:8084/xmlrpc";
+  my $debug = 0;
+  my $encoding = 'ISO-8859-1';
+
+  my $client = Frontier::Client->new(
+                'url' => $control_server_url,
+                'debug' => $debug,
+                'encoding' => $encoding,
+  );
+    
+  # Some example procedure calls:
+  my $host_id_aref        = $client->call('host.getHostByHostname', $name);
+  my $host_name           = $client->call('host.getHostname', $host_id);
+  my $host_map            = $client->call('host.getHostAsMap', $host_id);
+  my $host_disk_safe_aref = $client->call('diskSafe.getDiskSfaeIDs' $host_id);
+
+Using CDP:
+  use CDP qw/:ALL/;
+  
+  # To Connect
+  my $u_name  = 'test';
+  my $pw      = 'password';
+  my $cdp_url = 'cdp.example.com';
+  
+  my $client = OpenCDP $cdp_url, $u_name, $pw;
+  
+  # Some example procedure calls
+  my $host_id_aref         = getHostByHostname $client, $name;
+  my $host_name            = getHostname $client, $host_id;  
+  my $host_map             = getHostAsMap $client, $host_id;
+  my $host_disk_safe_aref  = getDiskSfaeIDs $client, $host_id;
 
 =head1 SEE ALSO
 
-Mention other useful documentation such as the documentation of
-related modules or operating system documentation (such as man pages
-in UNIX), or any relevant external documentation such as RFCs or
-standards.
-
-If you have a mailing list set up for your module, mention it here.
-
-If you have a web site set up for your module, mention it here.
+R1Soft API Documentation:
+  http://wiki.r1soft.com/display/pdf/CDP+Server+API+Guide
 
 =head1 AUTHOR
 
-jon, E<lt>jon@E<gt>
+Please Feel Free to contact me with any questions, comments, or suggestions.
+
+Jon A, E<lt>jon[replacewithat]cyberspacelogistics[replacewithdot]comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -233,5 +294,4 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.1 or,
 at your option, any later version of Perl 5 you may have available.
 
-
 =cut
